@@ -20,28 +20,23 @@
 
 #include <gtest/gtest.h>
 
-#ifndef _GNU_SOURCE
-# define _GNU_SOURCE  // for asprintf
-#endif
-#include <stdio.h>
+#include <cstdio>
 
 
-#include <config.h>  // for PACKAGE_VERSION
-#include <uriparser/UriBase.h>
+#include "UriConfig.h"  // for PACKAGE_VERSION
+#include <uriparser/Uri.h>
 
 
 TEST(VersionSuite, EnsureVersionDefinesInSync) {
-	char * INSIDE_VERSION = NULL;
-	const int bytes_printed = asprintf(&INSIDE_VERSION, "%d.%d.%d%s",
+	char INSIDE_VERSION[256];
+	const int bytes_printed = sprintf(INSIDE_VERSION, "%d.%d.%d%s",
 			URI_VER_MAJOR, URI_VER_MINOR, URI_VER_RELEASE, URI_VER_SUFFIX_ANSI);
-	ASSERT_TRUE(bytes_printed != -1);
+	ASSERT_NE(bytes_printed, -1);
+	EXPECT_STREQ(INSIDE_VERSION, PACKAGE_VERSION);
+}
 
-	const bool equal = !strcmp(INSIDE_VERSION, PACKAGE_VERSION);
-	if (! equal) {
-		printf("Inside/outside version mismatch detected:\n");
-		printf("  Tarball version:         <%s>\n", PACKAGE_VERSION);
-		printf("  Header defines version:  <%s>\n", INSIDE_VERSION);
-	}
-	free(INSIDE_VERSION);
-	ASSERT_TRUE(equal);
+TEST(VersionSuite, EnsureRuntimeVersionAsExpected) {
+	// NOTE: This needs a bump for every release
+	EXPECT_STREQ(uriBaseRuntimeVersionA(),  "0.9.9");
+	EXPECT_STREQ(uriBaseRuntimeVersionW(), L"0.9.9");
 }
